<?php
    class Usuario_model extends CI_Model 
    {
    	function __construct()
        {
            parent::__construct();
            $this->load->library('mongo');
        }

        function registrar_nuevo_usuario($usuario)
        {
        	return $this->mongo->insertar('usuarios', $usuario);
        }

        function validar_cuenta($token)
        {
        	$bulk = new MongoDB\Driver\BulkWrite;
        	$bulk->update(
			    ['token' => $token],
			    ['$set' => [
			    	'activo' => true 
			    ]],
			    ['multi' => false, 'upsert' => false]
			);

			return $this->mongo->modificar('usuarios', null, $bulk);
        }

        function validar_correo($correo)
        {
        	$filter = array('correo' => $correo);
        	return $this->mongo->query('usuarios', $filter);
        }

        function buscar_contraparte($empresa, $tipo)
        {
            $tipo = ($tipo == 'trabajador' ? 'empleador' : 'trabajador');
            $filter = array(
                'empresa_asociada' => $empresa,
                'tipo_asociacion' => $tipo
            );

            return $this->mongo->query('usuarios', $filter);
        }

        function obtener($coleccion = '', $id = null)
        {
            $filter = array();

            if($id != null){
                $_id = null;
                try {
                    $_id = new MongoDB\BSON\ObjectId("$id");
                    $filter = array('_id' => $_id);
                } catch (Exception $e) {
                    return array();
                }
            }
            return $this->mongo->query($coleccion, $filter);
        }

        function borrar_perfil_usuario($id)
        {
            $bulk = new MongoDB\Driver\BulkWrite;
            $_id = null;
            if($id != null){
                try {
                    $_id = new MongoDB\BSON\ObjectId("$id");
                } catch (Exception $e) {
                    return false;
                }
            }

            $bulk->update(
                ['_id' => $_id],
                ['$unset' => [
                    'empresa_asociada' => 1,
                    'tipo_asociacion' => 1,
                    'encuestas_asignadas' => 1
                ]],
                ['multi' => false, 'upsert' => false]
            );

            return $this->mongo->modificar('usuarios', null, $bulk);
        }

        function asociar_usuario_con_empresa($id, $id_empresa, $tipo_asociacion)
        {
            $bulk = new MongoDB\Driver\BulkWrite;
            $_id = null;
            if($id != null){
                try {
                    $_id = new MongoDB\BSON\ObjectId("$id");
                } catch (Exception $e) {
                    return false;
                }
            }

            $bulk->update(
                ['_id' => $_id],
                ['$set' => [
                    'empresa_asociada' => $id_empresa,
                    'tipo_asociacion' => $tipo_asociacion,
                    'encuestas_asignadas' => array()
                ]],
                ['multi' => false, 'upsert' => false]
            );

            return $this->mongo->modificar('usuarios', null, $bulk);
        }

        function agregar_formulario_a_usuario($id, $formulario)
        {
            $bulk = new MongoDB\Driver\BulkWrite;
            $_id = null;
            if($id != null){
                try {
                    $_id = new MongoDB\BSON\ObjectId("$id");
                } catch (Exception $e) {
                    return false;
                }
            }

            $bulk->update(
                ['_id' => $_id],
                ['$push' => array('encuestas_asignadas' => array('id' => $formulario))],
                ['multi' => false, 'upsert' => false]
            );

            return $this->mongo->modificar('usuarios', null, $bulk);
        }

        function habilitar_usuario_responder($id, $estado)
        {
            $bulk = new MongoDB\Driver\BulkWrite;
            $_id = null;
            if($id != null){
                try {
                    $_id = new MongoDB\BSON\ObjectId("$id");
                } catch (Exception $e) {
                    return false;
                }
            }

            $bulk->update(
                ['_id' => $_id],
                ['$set' => [
                    'habilitado_responder' => $estado
                ]],
                ['multi' => false, 'upsert' => false]
            );

            return $this->mongo->modificar('usuarios', null, $bulk);
        }
    }
